#
# spec file for package mnemosyne
#
# Copyright (c) 2012 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           mnemosyne
Summary:        Flash-card learning tool
License:        GPL-2.0+
Group:          Productivity/Other
Version:        2.6
Release:        lp150.1.1
Source0:        https://sourceforge.net/projects/%{name}-proj/files/%{name}/%{name}-%{version}/Mnemosyne-%{version}.tar.gz
Source1:        %{name}.png
Source2:        %{name}.desktop
Source3:        AUTHORS
Url:            http://www.mnemosyne-proj.org/
BuildRequires:  dos2unix
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
%if 0%{?suse_version}
BuildRequires:  update-desktop-files
%endif
Requires:       python3-CherryPy
Requires:       python3-matplotlib
Requires:       python3-qt5
Requires:       python3-WebOb
%if 0%{?suse_version}
Recommends:     texlive-latex
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
Mnemosyne resembles a traditional flash-card program but with an
important twist: it uses a sophisticated algorithm to schedule the best
time for a card to come up for review.

%lang_package

%prep
%setup -q  -n Mnemosyne-%{version}
# rpmlint
find -name "*.py" | xargs -r dos2unix 
find -name "README.md" | xargs -r dos2unix 
find -name "ChangeLog" | xargs -r dos2unix 

%build
cp %{S:3} ./
env CFLAGS="%{optflags}" \
python3 setup.py build

%install
python3 setup.py install \
        --root="%{buildroot}" \
        --prefix="%{_prefix}" \
        --install-lib="%{python3_sitelib}"

install -Dm644 %{SOURCE2} %buildroot/%_datadir/applications/%{name}.desktop
test -d %buildroot/%_datadir/icons && rm -rf %buildroot/%_datadir/icons

%find_lang mnemosyne
%if 0%{?suse_version}
%suse_update_desktop_file -i -n -r %{name} Education Languages
%endif

%files
%defattr(-,root,root,-)
%doc ChangeLog README.md AUTHORS
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/mnemosyne.png
%{python3_sitelib}/%{name}
%{python3_sitelib}/Mnemosyne*
%{python3_sitelib}/openSM2sync

%files lang -f %{name}.lang

%changelog
* Wed Aug  1 2018 ecsos@opensuse.org
- update to 2.6
  - Import of Anki databases (both *.anki2 and *.apgk) as well as
    possibility to edit these M-sided card types (though not yet in
    a way that would change the number of sister cards).
  - Fix display of question in the card browser in case you
    configured Mnemosyne to show question and answer in the same
    window.
  - Fix bugs with increase of non-latin fonts
  - Fix cornercase bug in RTL handler
  - Upgrade to latest version of libraries (PyQt, Python,
    Matplotlib).
  - Improve keyboard shortcuts.
  - Fixes to the behaviour of the Edit dialog of the Card Browser.
  - Also save window size when exiting window by pressing escape.
  - Fix display of map cards when showing Q and A in the same box.
  - Disallow renaming a single tag to multiple tags in the tag tree
    widget.
  - In case you get crashes in the browser when trying to display
    only untagged cards, you can now run 'File - Compact -
    Defragment database' to fix this
  - Fix crash in headless server.
  - Fix crashes when running separate scripts.
- changes from 2.5
  - New feature: Study Modes, allowing you to e.g. only study
    unlearned cards. The Cramming scheduler is also migrated to
    this functionality.
  - Added option to "Configure Mnemosyne" to affect how cards are
    displayed, in two boxes with fixed size, two boxes with
    adaptive size, or a single box top aligned.
  - Tweaks to tag combobox.
  - Updated to PyQt 5.8.2.
  - Scaling for high-definition displays now enabled by default.
    (start with --disable-high-dpi-scaling if you prefer the
    previous behaviour).
  - Fix crash when deleting unused media files.
  - Small performance optimisations in the database.
  - Fix crash in configuration widget under Linux with some fonts
  (e.g. Google Noto fonts).
  - Fix crash when selecting negative tags.
  - Fix keyboard shortcuts not working sometimes.
  - Improved compatibility with different Qt versions under Linux
  - When setting the fonts for all the card types at once,
    the dialog will now correctly remember the setting.
  - Added warning if OpenGL libraries are missing under Linux
  - Try and work around cases where the progress bar after sync
    wouldn't close under Linux.
  - Fix crash when running with the --debug option.
- changes from 2.4.1
  - Updated to PyQt 5.7.1.
  - Fix broken cramming plugin.
  - Fix encoding problems with import and export
  - Improve subdirectory handling.
  - Make configuration storing more thread-safe.
  - Warn if an old plugin needs to be updated.
  - Location and size of 'Add cards' window is saved again.
  - Fix removing tags through card browser.
  - Fix loss of keyboard focus when switching back to the main
    window.
  - Fixed crash in card browser when working with forbidden tags
  - Fix autoscaling of Q and A sometimes not working under Linux.
  - Fix error related missing idna encoding when starting server
  - Fix error related to upgrading from very old databases.
  - Fix for latest version of cherrypy unbundling its WSGIserver.
  - New command line option "--qt-opengl" which can be set to
    either 'desktop', 'angle' or 'software', which you can play
    around with if you have display issues.
- changes from 2.4
  - Upgraded all code to Python3 and PyQt5, so that Mnemosyne no
    longer depends on libraries which are gradually becoming
    unsupported.
  - The move to PyQt5 enabled to show progress bars with
    percentages for certain long operations like initial sync.
  - Improved startup speed.
  - New command line option "--high-dpi-scaling" to enable scaling
    for displays with high DPI values. Not enabled by default
    because it can cause some issues with multiple connected
    displays.
  - Tag combobox now expands to give suggestions for tags also
    when using more than one tag.
- remove mnemosyne-install-path.patch, because now in upstream
- cleanup spec
* Tue May  3 2016 ecsos@opensuse.org
- update to 2.3.6
  - Logs older than 1 year are now automatically archived in a
    separate file, which is not backed up all the time, speeding
    up e.g. the sync process.
  - The card browser now supports more html formatting,
    e.g. ruby tags.
  - URLs in cards in the review widget now open in an external
    browser, rather than the internal Qt webview which does not
    have back buttons e.g..
  - Only changing a card type in the 'Edit current card' dialog now
    works again
  - Failed cards no longer are listed as overdue in the card
    browser
  - When adding a tag with the same name both on client and server
    before syncing, rename one of these tags. Users still need to
    unify and activate the tags though
  - Added a --version command line argument to display the version
  - Also accept files with *.tsv extention when importing
    tab-separated data
  - Don't leave the 'Client Logging in...'' dialog on the sync
    server open in case the client provides a wrong password
  - Fixed formatting when using 'db_media:///' in cards with
    javascript
* Tue Dec  8 2015 ecsos@opensuse.org
- update to 2.3.5
  - Fix editing of empty fields
  - Fix crash when compacting database
  - Fix sound system under Linux
  - Make determining local IP address more robust
- update to 2.3.4
  - When importing another database with learning data, don't reset
  the creation and modification times of cards.
  - When switching card sets, no longer keep showing an unlearned
  card that was being asked when the switch took place, but give
  precedence to scheduled cards.
  - Improve robustness of sync protocol.
  - When moving to a next card, kill the audio from the previous
  card.
  - Multiple media files per card now works in conjunction with the
  'start' and 'stop' options.
  - When editing a card from the card browser, PgUp and PgDown no
  longer discard the changes
  - Fixed issue where creating clones of card types would sometimes
  clone the wrong card type.
  - Prefill tag behaviour plugin: don't update the last used tags
  when editing a card, only when adding new cards.
  - Better runtime documentation for the '(De)activate cards' dialog
  - Allow Cntl-C to copy text from question if answer is showing
  - Fix Windows-specific bug, where Mnemosyne would not notice that
  you were trying to open a backup and would not take the
  appropriate actions.
  - When running the sync server on e.g. a headless machine which
  does not have latex installed, don't waste time looking for
  updated latex cards.
  - Fix regression where a currently active set would not show up as
  highlighed in the 'saved sets' panel when starting
  '(de)activate cards'
  - Improve run-time help with respect to editing a saved set
  - To work around bugs in Qt under Linux, media are also played
  using mplayer, just like under Windows
  - Fix problems with not detecting autorepeat when pressing grade
  buttons
  - Fix RTL issues (reported by Mateusz Konieczny).
  - Fix potential bug when exporting clones of cloned card types.
- update to 2.3.3
  - Fix regression where it was not possible to grade map cards
  - Also allow mass conversion of cards to Cloze and Sentence card
  types
  - Change ',' to ' - ' when importing legacy tag names
  - Fix some keyboard shortcuts while displaying map cards
* Thu Feb 26 2015 ecsos@opensuse.org
- update to 2.3.2
  - Option to merge databases (under File - Import - Mnemosyne
  2.x *.db files).
  - Make sure latex files are always pregenerated before sync
  - Fix error syncing filenames containing double dots
  - Strip control characters from strings when exporting and syncing
  - Smart sorting of card types in dialog boxes-Fix when importing
  1.x databases containing a single quote in a media filename
  - Don't replace newline with <br> inside textarea tags
  - Fix crash when running in headless mode after having run with
  the GUI
  - Fix handling of media filenames containing '#'
  - Don't crash the SQL engine if you have more than 1000 tags
  - Fix regression in merging and editing duplicate cards
  - Update the window title on a sync server if a different
  database was loaded.
  - Make upgrading from 2.3 config database more robust
  - Better error handling when trying to load a database which
  no longer exists in its previous location.
  - Make sure we can run on systems with PyQt5 installed
  - The "db_media:" tag now expands to an absolute path on
  all systems
  - The local timezone is now stored in the science logs.
* Sat Dec  6 2014 lars@linux-schulserver.de
- update to version 2.3.1
  (details in changelog and on http://www.mnemosyne-proj.org/whats-new)
- require python-webob
* Sat Apr 26 2014 ecsos@opensuse.org
- update to version 2.3
  (details in changelog and on http://www.mnemosyne-proj.org/whats-new)
* Fri Oct 26 2012 badshah400@gmail.com
- Spec file cleanups:
  + Update License to spdx.org norms
  + Add Copyright preamble
  + Package an AUTHORS file instead of specifying the authors with
    the Description in spec file
  + Miscellaneous formatting fixes.
* Fri Oct 26 2012 lijewski.stefan@gmail.com
- update to version 2.1 (details in changelog and on
  http://www.mnemosyne-proj.org/whats-new)
* Mon Jul 16 2012 lijewski.stefan@gmail.com
- update to version 2.0 (see changelog)
* Mon Apr 11 2011 lijewski.stefan@gmail.com
- added recommended dependency for latex
* Fri Mar 25 2011 lijewski.stefan@gmail.com
- added dependency for python-imaging module-
* Thu Mar 17 2011 lijewski.stefan@gmail.com
- fix build on x86_64
* Wed Mar 16 2011 lijewski.stefan@gmail.com
-update to version 1.2.2-
* Mon Nov 24 2008 lars@linux-schulserver.de
- initial package 1.1.1 for openSUSE-Education
